From 515ee9f9e624f726a4bdef2341c88c89912f4b0d Mon Sep 17 00:00:00 2001
From: Ming Yang <yangming73@huawei.com>
Date: Thu, 25 Feb 2021 18:58:46 +0800
Subject: [PATCH 1/4] exit: add exit code when stratovirt exit abnormally.

Signed-off-by: Ming Yang <yangming73@huawei.com>
---
 machine_manager/src/signal_handler.rs |  4 ++--
 src/main.rs                           | 20 +++++++++++++-------
 2 files changed, 15 insertions(+), 9 deletions(-)

diff --git a/machine_manager/src/signal_handler.rs b/machine_manager/src/signal_handler.rs
index 79af118..d185c7e 100644
--- a/machine_manager/src/signal_handler.rs
+++ b/machine_manager/src/signal_handler.rs
@@ -17,7 +17,7 @@ use libc::{c_int, c_void, siginfo_t};
 use vmm_sys_util::signal::register_signal_handler;
 use vmm_sys_util::terminal::Terminal;
 
-const VM_EXIT_GENE_ERR: i32 = -1;
+pub const VM_EXIT_GENE_ERR: i32 = -1;
 const SYSTEMCALL_OFFSET: isize = 6;
 
 fn basic_clean() {
@@ -32,7 +32,7 @@ fn basic_clean() {
         .expect("Failed to set terminal to canon mode.");
 }
 
-fn exit_with_code(code: i32) {
+pub fn exit_with_code(code: i32) {
     // Safe, because the basic_clean function has been executed before exit.
     unsafe {
         libc::_exit(code);
diff --git a/src/main.rs b/src/main.rs
index e6dffbc..5424994 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -23,14 +23,15 @@ use std::sync::{Arc, Mutex};
 use vmm_sys_util::terminal::Terminal;
 
 use device_model::{balloon_allow_list, register_seccomp, syscall_allow_list, LightMachine};
-use machine_manager::qmp::QmpChannel;
-use machine_manager::socket::Socket;
 use machine_manager::{
     cmdline::{check_api_channel, create_args_parser, create_vmconfig},
+    config::VmConfig,
     event_loop::EventLoop,
+    qmp::QmpChannel,
+    signal_handler::{exit_with_code, register_kill_signal, VM_EXIT_GENE_ERR},
+    socket::Socket,
     temp_cleaner::TempCleaner,
 };
-use machine_manager::{config::VmConfig, signal_handler::register_kill_signal};
 use util::loop_context::EventNotifierHelper;
 use util::unix::limit_permission;
 use util::{arg_parser, daemonize::daemonize, logger};
@@ -85,13 +86,18 @@ fn run() -> Result<()> {
 
         // clean temporary file
         TempCleaner::clean();
+        exit_with_code(VM_EXIT_GENE_ERR);
     }));
 
     let vm_config: VmConfig = create_vmconfig(&cmd_args)?;
     info!("VmConfig is {:?}", vm_config);
 
     match real_main(&cmd_args, vm_config) {
-        Ok(()) => info!("MainLoop over, Vm exit"),
+        Ok(()) => {
+            info!("MainLoop over, Vm exit");
+            // clean temporary file
+            TempCleaner::clean();
+        }
         Err(ref e) => {
             std::io::stdin()
                 .lock()
@@ -107,12 +113,12 @@ fn run() -> Result<()> {
                 )
                 .expect("Failed to write to stderr");
             }
+            // clean temporary file
+            TempCleaner::clean();
+            exit_with_code(VM_EXIT_GENE_ERR);
         }
     }
 
-    // clean temporary file
-    TempCleaner::clean();
-
     Ok(())
 }
 
-- 
2.27.0

